HelperBase class abstract

The image cache interface

Constructors

HelperBase()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
threadOperation → ThreadOperationBase
no setter

Methods

add(ImageInfoData imageInfo) → void
clearCache() → Future<void>
Clear DisposableCachedImage storage cache.
getAssetBytes(String imagePath) → Future<Uint8List>
getBytes(String key) → Future<Uint8List?>
getImageInfo(String key) → ImageInfoData?
getLocalBytes(String imagePath) → Future<Uint8List>
init(bool enableWebCache, int maximumDownload) → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getPlatformInstance() → HelperBase