ThreadOperationBase class abstract

Constructors

ThreadOperationBase()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addToCache({required String key, required int width, required int height, required Uint8List bytes}) → Future<void>
cancelDownload(String url) → void
clearData() → Future<void>
getBytes(String key) → Future<Uint8List?>
getNetworkBytes(String url, Map<String, String>? headers) → Stream
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited