ImageInfoData class

class to handle the necessary image data

Constructors

ImageInfoData({required int? height, required int? width, required String key, Uint8List? imageBytes})
const
ImageInfoData.fromMap(Map<String, dynamic> map, String key)
factory
ImageInfoData.init(String key)
const

Properties

hashCode → int
The hash code for this object.
no setteroverride
height → int?
final
imageBytes → Uint8List?
final
key → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int?
final

Methods

copyWith({Uint8List? imageBytes, String? key, int? height, int? width}) → ImageInfoData
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
sizeToMap() → Map<String, int>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override